==> kubernetes-model-autoscaling-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/PodsMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodsMetricSourceFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMetricName();
  public A withMetricName(java.lang.String metricName);
  public java.lang.Boolean hasMetricName();
  
  /**
   * Method is deprecated. use withMetricName instead.
   */
  @java.lang.Deprecated
  public A withNewMetricName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue();
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue);
  public java.lang.Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format);
  public A withNewTargetAverageValue(java.lang.String amount);
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> kubernetes-model-autoscaling-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/PodsMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodsMetricSourceFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMetricName();
  public A withMetricName(java.lang.String metricName);
  public java.lang.Boolean hasMetricName();
  
  /**
   * Method is deprecated. use withMetricName instead.
   */
  @java.lang.Deprecated
  public A withNewMetricName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue();
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue);
  public java.lang.Boolean hasTargetAverageValue();
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format);
  public A withNewTargetAverageValue(java.lang.String amount);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
